==> faith-0.0.33.tar.gz: faith-0.0.33/tests/report/test_accountperformance.py <==
from report.accountperformance.accountperformance import AccountPerformance
from report.symbolhistory.symbolhistory import SymbolHistory


def test_account_performance_gen_data(symbol_history: SymbolHistory) -> None:
    account_performance = AccountPerformance(symbol_history=symbol_history)
    data = account_performance._gen_data('Week')
    example = [
        ['Week', 'Settled Profit from Stock', 'Settled Profit from Option', 'Total Settled Profit'],
        ['2018-04-30', '$0.00', '$32.00', '$32.00'],
        ['2018-05-14', '$0.00', '$93.00', '$93.00'],
        ['2018-05-21', '$0.00', '$-738.00', '$-738.00'],
        ['2018-05-28', '$0.00', '$-870.00', '$-870.00'],
        ['2018-06-18', '$0.00', '$-42.00', '$-42.00'],
        ['2018-06-25', '$-137.00', '$-148.00', '$-285.00'],
        ['2018-07-09', '$363.45', '$75.00', '$438.45'],
        ['2018-07-16', '$266.90', '$-135.00', '$131.90'],
        ['2018-07-23', '$0.00', '$180.00', '$180.00'],
        ['2018-07-30', '$0.00', '$215.00', '$215.00'],
        ['2018-08-06', '$0.00', '$335.00', '$335.00'],
        ['2018-08-13', '$0.00', '$276.00', '$276.00'],
        ['2018-08-20', '$885.00', '$676.00', '$1,561.00'],
        ['2018-08-27', '$0.00', '$1,464.14', '$1,464.14'],
        ['2018-09-03', '$274.00', '$718.86', '$992.86'],
        ['2018-09-10', '$0.00', '$1,542.00', '$1,542.00'],
        ['2018-09-17', '$0.00', '$1,530.00', '$1,530.00'],
        ['2018-09-24', '$1,681.98', '$706.00', '$2,387.98'],
        ['2018-10-01', '$-1,749.00', '$630.00', '$-1,119.00'],
        ['2018-10-08', '$0.00', '$57.00', '$57.00'],
        ['2018-10-15', '$0.00', '$117.00', '$117.00'],
        ['2018-10-22', '$-9,128.91', '$-80.00', '$-9,208.91'],
        ['2018-10-29', '$0.00', '$22.00', '$22.00'],
        ['2018-11-05', '$0.00', '$1,357.00', '$1,357.00'],
        ['2018-11-12', '$-2,557.90', '$-3,078.00', '$-5,635.90'],
        ['2018-11-19', '$0.00', '$-255.00', '$-255.00'],
        ['2018-11-26', '$-578.43', '$369.00', '$-209.43'],
        ['2018-12-03', '$2,710.00', '$66.00', '$2,776.00'],
        ['2018-12-10', '$-1,221.88', '$0.00', '$-1,221.88'],
        ['2018-12-17', '$0.00', '$-6,200.00', '$-6,200.00'],
        ['2019-01-07', '$-1,412.37', '$0.00', '$-1,412.37'],
        ['2019-01-14', '$-525.36', '$82.00', '$-443.36'],
        ['2019-01-28', '$0.00', '$78.00', '$78.00'],
        ['2019-02-04', '$-6,788.00', '$-618.00', '$-7,406.00'],
        ['2019-02-18', '$555.00', '$-68.00', '$487.00'],
        ['2019-03-04', '$727.50', '$-500.00', '$227.50'],
        ['2019-03-11', '$0.00', '$-350.00', '$-350.00'],
        ['2019-04-01', '$750.00', '$100.00', '$850.00'],
        ['2019-04-08', '$0.00', '$135.00', '$135.00'],
        ['2019-04-15', '$0.00', '$925.00', '$925.00'],
        ['2019-04-22', '$21.50', '$217.00', '$238.50'],
        ['2019-04-29', '$879.50', '$731.00', '$1,610.50'],
        ['2019-05-06', '$0.00', '$821.00', '$821.00'],
        ['2019-05-13', '$0.00', '$2,330.00', '$2,330.00'],
        ['2019-05-20', '$95.00', '$892.00', '$987.00'],
        ['2019-05-27', '$0.00', '$1,154.00', '$1,154.00'],
        ['2019-06-03', '$1,073.83', '$1,151.00', '$2,224.83'],
        ['2019-06-10', '$0.00', '$1,480.00', '$1,480.00'],
        ['2019-06-17', '$924.32', '$1,740.00', '$2,664.32'],
        ['2019-06-24', '$-217.89', '$2,243.00', '$2,025.11'],
        ['2019-07-01', '$6,282.97', '$1,802.00', '$8,084.97'],
        ['2019-07-08', '$5,825.38', '$1,535.00', '$7,360.38'],
        ['2019-07-15', '$125.00', '$3,561.00', '$3,686.00'],
        ['2019-07-22', '$1,484.00', '$2,915.00', '$4,399.00'],
        ['2019-07-29', '$0.00', '$2,844.00', '$2,844.00'],
        ['2019-08-05', '$112.00', '$3,744.00', '$3,856.00'],
        ['2019-08-12', '$154.00', '$1,393.00', '$1,547.00'],
        ['2019-08-19', '$-3,532.00', '$6,545.00', '$3,013.00'],
        ['2019-08-26', '$0.00', '$4,039.00', '$4,039.00'],
        ['2019-09-02', '$45.00', '$2,860.00', '$2,905.00'],
        ['2019-09-09', '$-20,376.80', '$5,357.00', '$-15,019.80'],
        ['2019-09-16', '$760.11', '$1,497.00', '$2,257.11'],
        ['2019-09-23', '$0.00', '$-1,759.00', '$-1,759.00'],
        ['2019-09-30', '$-7,480.00', '$4,007.00', '$-3,473.00'],
        ['2019-10-07', '$0.00', '$2,069.00', '$2,069.00'],
    ]
    for i in range(len(example)):
        assert example[i] == data[i]


def test_account_performance_gen_data_sq(symbol_history: SymbolHistory) -> None:
    account_performance = AccountPerformance(symbol_history=symbol_history)
    data = account_performance._gen_data(interval='Week', symbol='SQ')
    example = [
        ['Week', 'Settled Profit from Stock', 'Settled Profit from Option', 'Total Settled Profit'],
        ['2018-06-18', '$0.00', '$-167.00', '$-167.00'],
        ['2018-07-23', '$0.00', '$52.00', '$52.00'],
        ['2018-07-30', '$0.00', '$125.00', '$125.00'],
        ['2018-09-03', '$274.00', '$340.00', '$614.00'],
        ['2018-09-10', '$0.00', '$565.00', '$565.00'],
        ['2018-09-24', '$1,621.98', '$25.00', '$1,646.98'],
        ['2018-10-01', '$0.00', '$315.00', '$315.00'],
        ['2018-11-05', '$0.00', '$120.00', '$120.00'],
        ['2018-11-12', '$0.00', '$265.00', '$265.00'],
        ['2018-11-26', '$-578.43', '$0.00', '$-578.43'],
        ['2018-12-10', '$-678.88', '$0.00', '$-678.88'],
        ['2019-01-07', '$-1,412.37', '$0.00', '$-1,412.37'],
        ['2019-01-14', '$43.82', '$0.00', '$43.82'],
        ['2019-04-08', '$0.00', '$60.00', '$60.00'],
        ['2019-04-29', '$0.00', '$64.00', '$64.00'],
        ['2019-05-06', '$0.00', '$111.00', '$111.00'],
        ['2019-05-27', '$0.00', '$24.00', '$24.00'],
        ['2019-06-17', '$0.00', '$28.00', '$28.00'],
        ['2019-06-24', '$0.00', '$48.00', '$48.00'],
        ['2019-07-08', '$5,500.26', '$0.00', '$5,500.26'],
        ['2019-07-22', '$730.00', '$0.00', '$730.00'],
        ['2019-08-05', '$0.00', '$797.00', '$797.00'],
        ['2019-08-12', '$0.00', '$730.00', '$730.00'],
        ['2019-08-26', '$0.00', '$1,540.00', '$1,540.00'],
        ['2019-09-02', '$0.00', '$530.00', '$530.00'],
        ['2019-09-09', '$0.00', '$1,020.00', '$1,020.00'],
        ['2019-09-23', '$0.00', '$384.00', '$384.00'],
        ['2019-09-30', '$0.00', '$390.00', '$390.00'],
        ['2019-10-07', '$0.00', '$416.00', '$416.00'],
        ['2019-10-14', '$0.00', '$-188.00', '$-188.00'],
        ['2019-10-21', '$0.00', '$305.00', '$305.00'],
    ]
    for i in range(len(data)):
        assert example[i] == data[i]


def test_show(symbol_history: SymbolHistory) -> None:
    account_performance = AccountPerformance(symbol_history=symbol_history)
    df = account_performance.gen_df(interval='Month')
    print(df)

==> faith-0.0.46.tar.gz: faith-0.0.46/tests/report/test_accountperformance.py <==
from report.accountperformance.accountperformance import AccountPerformance
from report.symbolhistory.symbolhistory import SymbolHistory


def test_account_performance_gen_data(symbol_history: SymbolHistory) -> None:
    account_performance = AccountPerformance(symbol_history=symbol_history)
    data = account_performance._gen_data('Week')
    example = [
        ['Week', 'Settled Profit from Stock', 'Settled Profit from Option', 'Total Settled Profit'],
        ['2018-04-30', '$0.00', '$32.00', '$32.00'],
        ['2018-05-14', '$0.00', '$93.00', '$93.00'],
        ['2018-05-21', '$0.00', '$-738.00', '$-738.00'],
        ['2018-05-28', '$0.00', '$-870.00', '$-870.00'],
        ['2018-06-18', '$0.00', '$-42.00', '$-42.00'],
        ['2018-06-25', '$-137.00', '$-148.00', '$-285.00'],
        ['2018-07-09', '$363.45', '$75.00', '$438.45'],
        ['2018-07-16', '$266.90', '$-135.00', '$131.90'],
        ['2018-07-23', '$0.00', '$180.00', '$180.00'],
        ['2018-07-30', '$0.00', '$215.00', '$215.00'],
        ['2018-08-06', '$0.00', '$335.00', '$335.00'],
        ['2018-08-13', '$0.00', '$276.00', '$276.00'],
        ['2018-08-20', '$885.00', '$676.00', '$1,561.00'],
        ['2018-08-27', '$0.00', '$1,464.14', '$1,464.14'],
        ['2018-09-03', '$274.00', '$718.86', '$992.86'],
        ['2018-09-10', '$0.00', '$1,542.00', '$1,542.00'],
        ['2018-09-17', '$0.00', '$1,530.00', '$1,530.00'],
        ['2018-09-24', '$1,681.98', '$706.00', '$2,387.98'],
        ['2018-10-01', '$-1,749.00', '$630.00', '$-1,119.00'],
        ['2018-10-08', '$0.00', '$57.00', '$57.00'],
        ['2018-10-15', '$0.00', '$117.00', '$117.00'],
        ['2018-10-22', '$-9,128.91', '$-80.00', '$-9,208.91'],
        ['2018-10-29', '$0.00', '$22.00', '$22.00'],
        ['2018-11-05', '$0.00', '$1,357.00', '$1,357.00'],
        ['2018-11-12', '$-2,557.90', '$-3,078.00', '$-5,635.90'],
        ['2018-11-19', '$0.00', '$-255.00', '$-255.00'],
        ['2018-11-26', '$-578.43', '$369.00', '$-209.43'],
        ['2018-12-03', '$2,710.00', '$66.00', '$2,776.00'],
        ['2018-12-10', '$-1,221.88', '$0.00', '$-1,221.88'],
        ['2018-12-17', '$0.00', '$-6,200.00', '$-6,200.00'],
        ['2019-01-07', '$-1,412.37', '$0.00', '$-1,412.37'],
        ['2019-01-14', '$-525.36', '$82.00', '$-443.36'],
        ['2019-01-28', '$0.00', '$78.00', '$78.00'],
        ['2019-02-04', '$1,486.00', '$-618.00', '$868.00'],
        ['2019-02-18', '$555.00', '$-68.00', '$487.00'],
        ['2019-03-04', '$727.50', '$-500.00', '$227.50'],
        ['2019-03-11', '$0.00', '$-350.00', '$-350.00'],
        ['2019-04-01', '$750.00', '$100.00', '$850.00'],
        ['2019-04-08', '$0.00', '$135.00', '$135.00'],
        ['2019-04-15', '$0.00', '$925.00', '$925.00'],
        ['2019-04-22', '$21.50', '$217.00', '$238.50'],
        ['2019-04-29', '$879.50', '$731.00', '$1,610.50'],
        ['2019-05-06', '$0.00', '$821.00', '$821.00'],
        ['2019-05-13', '$0.00', '$2,330.00', '$2,330.00'],
        ['2019-05-20', '$95.00', '$892.00', '$987.00'],
        ['2019-05-27', '$0.00', '$1,154.00', '$1,154.00'],
        ['2019-06-03', '$1,073.83', '$1,151.00', '$2,224.83'],
        ['2019-06-10', '$0.00', '$1,480.00', '$1,480.00'],
        ['2019-06-17', '$924.32', '$1,740.00', '$2,664.32'],
        ['2019-06-24', '$-217.89', '$2,243.00', '$2,025.11'],
        ['2019-07-01', '$6,282.97', '$1,802.00', '$8,084.97'],
        ['2019-07-08', '$5,825.38', '$1,535.00', '$7,360.38'],
        ['2019-07-15', '$125.00', '$3,561.00', '$3,686.00'],
        ['2019-07-22', '$1,484.00', '$2,915.00', '$4,399.00'],
        ['2019-07-29', '$0.00', '$2,844.00', '$2,844.00'],
        ['2019-08-05', '$112.00', '$3,744.00', '$3,856.00'],
        ['2019-08-12', '$154.00', '$1,393.00', '$1,547.00'],
        ['2019-08-19', '$-3,532.00', '$6,545.00', '$3,013.00'],
        ['2019-08-26', '$0.00', '$4,039.00', '$4,039.00'],
        ['2019-09-02', '$45.00', '$2,860.00', '$2,905.00'],
        ['2019-09-09', '$-20,376.80', '$5,357.00', '$-15,019.80'],
        ['2019-09-16', '$760.11', '$1,497.00', '$2,257.11'],
        ['2019-09-23', '$0.00', '$-1,759.00', '$-1,759.00'],
        ['2019-09-30', '$-7,480.00', '$4,007.00', '$-3,473.00'],
        ['2019-10-07', '$0.00', '$2,069.00', '$2,069.00'],
        ['2019-10-14', '$0.00', '$177.00', '$177.00'],
        ['2019-10-21', '$3,824.56', '$2,706.00', '$6,530.56'],
        ['2019-10-28', '$0.00', '$10,606.00', '$10,606.00'],
        ['2019-11-04', '$-3,109.40', '$1,338.00', '$-1,771.40'],
        ['2019-11-11', '$-6,709.00', '$-9,310.00', '$-16,019.00'],
        ['2019-11-18', '$-2,224.00', '$1,585.00', '$-639.00'],
    ]
    for i in range(len(example)):
        assert example[i] == data[i]


def test_account_performance_gen_data_sq(symbol_history: SymbolHistory) -> None:
    account_performance = AccountPerformance(symbol_history=symbol_history)
    data = account_performance._gen_data(interval='Week', symbol='SQ')
    example = [
        ['Week', 'Settled Profit from Stock', 'Settled Profit from Option', 'Total Settled Profit'],
        ['2018-06-18', '$0.00', '$-167.00', '$-167.00'],
        ['2018-07-23', '$0.00', '$52.00', '$52.00'],
        ['2018-07-30', '$0.00', '$125.00', '$125.00'],
        ['2018-09-03', '$274.00', '$340.00', '$614.00'],
        ['2018-09-10', '$0.00', '$565.00', '$565.00'],
        ['2018-09-24', '$1,621.98', '$25.00', '$1,646.98'],
        ['2018-10-01', '$0.00', '$315.00', '$315.00'],
        ['2018-11-05', '$0.00', '$120.00', '$120.00'],
        ['2018-11-12', '$0.00', '$265.00', '$265.00'],
        ['2018-11-26', '$-578.43', '$0.00', '$-578.43'],
        ['2018-12-10', '$-678.88', '$0.00', '$-678.88'],
        ['2019-01-07', '$-1,412.37', '$0.00', '$-1,412.37'],
        ['2019-01-14', '$43.82', '$0.00', '$43.82'],
        ['2019-04-08', '$0.00', '$60.00', '$60.00'],
        ['2019-04-29', '$0.00', '$64.00', '$64.00'],
        ['2019-05-06', '$0.00', '$111.00', '$111.00'],
        ['2019-05-27', '$0.00', '$24.00', '$24.00'],
        ['2019-06-17', '$0.00', '$28.00', '$28.00'],
        ['2019-06-24', '$0.00', '$48.00', '$48.00'],
        ['2019-07-08', '$5,500.26', '$0.00', '$5,500.26'],
        ['2019-07-22', '$730.00', '$0.00', '$730.00'],
        ['2019-08-05', '$0.00', '$797.00', '$797.00'],
        ['2019-08-12', '$0.00', '$730.00', '$730.00'],
        ['2019-08-26', '$0.00', '$1,540.00', '$1,540.00'],
        ['2019-09-02', '$0.00', '$530.00', '$530.00'],
        ['2019-09-09', '$0.00', '$1,020.00', '$1,020.00'],
        ['2019-09-23', '$0.00', '$384.00', '$384.00'],
        ['2019-09-30', '$0.00', '$390.00', '$390.00'],
        ['2019-10-07', '$0.00', '$416.00', '$416.00'],
        ['2019-10-14', '$0.00', '$-188.00', '$-188.00'],
        ['2019-10-21', '$0.00', '$305.00', '$305.00'],
    ]
    for i in range(len(example)):
        assert example[i] == data[i]
